@@ -616,8 +616,8 @@ setMethodS3(
 
 		# Use the package data directory if loaded:
 		if(length(intersect(search(),c("package:phylosim"))) == 1){
-			RDATDIR<-paste(.path.package("phylosim"),"/data/",sep="");
-			PAMLDIR<-paste(.path.package("phylosim"),"/extdata/",sep="");
+			RDATDIR<-paste(path.package("phylosim"),"/data/",sep="");
+			PAMLDIR<-paste(path.package("phylosim"),"/extdata/",sep="");
 		}
 		
 		rdname<-paste(RDATDIR,"/",name,".RData",sep="");
